Module function

Module function 

Create application-defined functions.

The functionality in this module is primarily exposed through Connection::create_scalar_function and Connection::create_aggregate_function.

Structs

Context
Describes the run-time environment of an application-defined function.
FunctionOptions

Traits

AggregateFunction
Implement an application-defined aggregate window function.
FromUserData
Constructor for aggregate functions.
LegacyAggregateFunction
Implement an application-defined aggregate function which cannot be used as a window function.
ScalarFunction
Trait for scalar functions. This trait is used with Connection::create_scalar_function_object to implement scalar functions that have a lifetime smaller than 'static. It is also possible to use closures and avoid implementing this trait, see Connection::create_scalar_function for details.
ToContextResult
A value that can be returned from an SQL function.