Context

Struct Context 

pub struct Context { /* private fields */ }
Describes the run-time environment of an application-defined function.

Implementations

Source

impl Context

pub fn db(&self) -> &Connection

Return a handle to the current database.

pub fn aux_data<T: 'static>(&self, idx: usize) -> Option<&mut T>

Retrieve data about a function parameter that was previously set with set_aux_data.

This method returns None if T is different from the data type that was stored previously.

pub fn set_aux_data<T: 'static>(&self, idx: usize, val: T)

Set the auxiliary data associated with the corresponding function parameter.

If some processing is necessary in order for a function parameter to be useful (for example, compiling a regular expression), this method can be used to cache the processed value in case it is later reused in the same query. The cached value can be retrieved with the aux_data method.

pub fn set_result(&self, val: impl ToContextResult) -> Result<()>

Assign the given value to the result of the function. This function always returns Ok.