Blob

Struct Blob 

pub struct Blob { /* private fields */ }
Represents an owned BLOB object.

This container allows BLOB data to be passed to SQLite without copying.

Implementations

Source

impl Blob

pub fn truncate(&mut self, len: usize)

Shorten the BLOB, keeping the first len elements and dropping the rest.

If len is greater than the BLOB’s current length, this has no effect.

pub fn into_raw(self) -> *mut c_void

Consumes the BLOB, returning a pointer to the data.

After calling this function, the caller is responsible for freeing the memory previously managed by Blob. The easiest way to do this is by passing ffi::drop_blob to SQLite when this value is consumed.

pub unsafe fn from_raw(ptr: *mut c_void) -> Blob

Construct a BLOB from a raw pointer.

After calling this function, the raw pointer is owned by the resulting Blob.

Safety

It is undefined behavior to call this method on anything other than a pointer that was returned by Blob::into_raw.

pub fn len(&self) -> usize

Return the length of the BLOB.

pub fn as_slice(&self) -> &[u8]

Get the underlying BLOB data.

pub fn as_mut_slice(&mut self) -> &mut [u8]

Mutably get the underlying BLOB data.