ColumnContext

Struct ColumnContext 

pub struct ColumnContext { /* private fields */ }
Describes the run-time environment of the VTabCursor::column method.

Implementations

Source

impl ColumnContext

pub fn db(&self) -> &Connection

Return a handle to the current database.

pub fn nochange(&self) -> bool

Return true if the column being fetched is part of an UPDATE operation during which the column value will not change.

See ValueRef::nochange for details and usage.

This method is provided as an optimization. It is permissible for this method to return false even if the value is unchanged. The virtual table implementation must function correctly even if this method were to always return false.

Requires SQLite 3.22.0. On earlier versions of SQLite, this method always returns false.

pub fn set_result(&self, val: impl ToContextResult) -> Result<()>

Assign the given value to the column. This function always returns Ok.