EponymousModule

Struct EponymousModule 

pub struct EponymousModule<'vtab, T: VTab<'vtab>> { /* private fields */ }
Describes an eponymous virtual table.

For this module, the virtual table is available ambiently in the database, but CREATE VIRTUAL TABLE can also be used to instantiate the table with alternative parameters.

See sqlite_ext_vtab for details on how to use this. The struct implementing the virtual table must implement VTab at a minimum. Any implementation of CreateVTab will be ignored.