EponymousOnlyModule

Struct EponymousOnlyModule 

pub struct EponymousOnlyModule<'vtab, T: VTab<'vtab>> { /* private fields */ }
Declare an eponymous-only virtual table.

For this virtual table, CREATE VIRTUAL TABLE is forbidden, but the table is ambiently available under the module name.

This feature requires SQLite 3.9.0 or above. Older versions of SQLite do not support eponymous virtual tables, meaning they require at least one CREATE VIRTUAL TABLE statement to be used. If supporting these versions of SQLite is desired, you can use StandardModule and return an error if there is an attempt to instantiate the virtual table more than once.

See sqlite_ext_vtab for details on how to use this. The struct implementing the virtual table must implement VTab at a minimum. Any implementation of CreateVTab will be ignored.