RenameVTab

Trait RenameVTab 

pub trait RenameVTab<'vtab>: VTab<'vtab> {
    // Required method
    fn rename(&'vtab self, name: &str) -> Result<()>;
}
A virtual table that supports ALTER TABLE RENAME.

Required Methods

fn rename(&'vtab self, name: &str) -> Result<()>

Corresponds to xRename, when ALTER TABLE RENAME is run on the virtual table. If this method returns Ok, then SQLite will disconnect this virtual table implementation and connect to a new implementation with the updated name.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors