RiskLevel

Enum RiskLevel 

pub enum RiskLevel {
    Innocuous,
    DirectOnly,
}
Indicate the risk level for a function or virtual table.

It is recommended that all functions and virtual table implementations set a risk level, but the default is RiskLevel::Innocuous if TRUSTED_SCHEMA=on and RiskLevel::DirectOnly otherwise.

See this discussion for more details about the motivation and implications.

Variants



Innocuous

An innocuous function or virtual table is one that can only read content from the database file in which it resides, and can only alter the database in which it resides.



DirectOnly

A direct-only function or virtual table has side-effects that go outside the database file in which it lives, or return information from outside of the database file.